Opinions - Delaware Courts - State of Delaware
Description: Court opinions from the Delaware Court system.

# Opinions and Orders

Please note: These electronic orders may contain computer-generated errors or other deviations from the official printed versions. In case of discrepancies between the print and electronic versions of orders, the print version controls. In case of discrepancies between the print and electronic versions of orders and any later official version of them, the later version controls.

Court:
Decision Date:
Search:

#### supreme court Opinions and Orders 176 Opinions

Results per page

Parties/Caption | Date | File Number | Court | Type | Judicial Officer | Description
--- | --- | --- | --- | --- | --- | ---
Ibirithi v. State | 04/05/2016 | 683, 2015 | Supreme Court | Criminal | Holland J. | Order
Matter of a Member of the Bar: Poliquin | 04/05/2016 | 129, 2016 | Supreme Court | Civil | Vaughn, J. | Order Office of Disciplinary Counsel (ODC)
Rosser v. State | 04/05/2016 | 470, 2015 | Supreme Court | Criminal | Strine C.J. | Order
Snyder, et al. v. New Castle County, et al. | 04/05/2016 | 519, 2015 | Supreme Court | Civil | Vaughn, J. | Order
The Lima Delta Company, et al. v. Global Aerospace, Inc., et al. | 04/05/2016 | 114, 2016 | Supreme Court | Civil | Valihura J. | Order
Wilmer v. State | 04/05/2016 | 628, 2015 | Supreme Court | Criminal | Strine C.J. | Order
Drummond v. State | 04/04/2016 | 99, 2016 | Supreme Court | Criminal | Valihura J. | Order
Goode v. State | 04/04/2016 | 276, 2015 | Supreme Court | Criminal | Seitz J. | Opinion
Jackson v. State | 04/04/2016 | 542, 2015 | Supreme Court | Criminal | Strine C.J. | Order
Pickens v. CitiMortgage, Inc. | 04/04/2016 | 387, 2015 | Supreme Court | Civil | Holland J. | Order
Evans v. State | 04/01/2016 | 121, 2016 | Supreme Court | Criminal | Valihura J. | Order
Humbertson v. State | 03/31/2016 | 599, 2015 | Supreme Court | Criminal | Valihura J. | Order
Infectious Disease Associates, P.A. v. Doe | 03/31/2016 | 62, 2016 | Supreme Court | Civil | Valihura J. | Order
Cook v. State | 03/29/2016 | 675, 2015 | Supreme Court | Criminal | Holland J. | Order
Roos Foods v. Magdalena Guardado | 03/28/2016 | 87, 2016 | Supreme Court | Civil | Valihura J. | Order
Masarone v. State | 03/24/2016 | 391, 2015 | Supreme Court | Criminal | Vaughn, J. | Opinion
Rossi v. State | 03/24/2016 | 374, 2015 | Supreme Court | Criminal | Strine C.J. | Opinion
Lanham v. State | 03/23/2016 | 665, 2015 | Supreme Court | Criminal | Seitz J. | Order
Matter of Evans | 03/23/2016 | 90, 2016 | Supreme Court | Criminal | Valihura J. | Order Writ of Mandamus
Smith v. JP Morgan Chase National Bank | 03/23/2016 | 43, 2016 | Supreme Court | Civil | Holland J. | Order
Kraft-Morris v. DFS, et al. | 03/22/2016 | 399, 2015 | Supreme Court | Civil | Vaughn, J. | Order
Rivera v. State | 03/21/2016 | 416, 2015 | Supreme Court | Criminal | Vaughn, J. | Order
Kane v. State | 03/17/2016 | 448, 2015 | Supreme Court | Criminal | Strine C.J. | Order
Walsh v. State | 03/16/2016 | 23, 2016 | Supreme Court | Criminal | Strine C.J. | Order
Walsh v. State | 03/16/2016 | 688, 2015 | Supreme Court | Civil | Seitz J. | Order

* C.=Chancellor or Commissioner C.J.=Chief Justice or Chief Judge J.=Justice or Judge M.=Master P.J.=President Judge R.J.=Resident Judge V.C.=Vice Chancellor